==> vixeny-0.1.20.tgz: package/test/exportable/composer.test.ts <==
import { composer, plugins } from "../../main.ts";
import { assertEquals } from "https://deno.land/std/testing/asserts.ts";
import { petitions } from "../../main.ts";

const dummyRequest = new Request("http://heyINeedTOGoToSleep.com/");
const opt = plugins.globalOptions({
  cyclePlugin: {
    hello: {
      name: Symbol.for("hello"),
      isFunction: true,
      type: undefined,
      f: () => () => () => "hello",
    },
  },
});

const commonPetition = petitions.common()({
  path: "/common",
  f: () => "common",
});

const responsePetition = petitions.response()({
  path: "/response",
  r: () => new Response("response"),
});

const requestPetition = petitions.standard()({
  path: "/response",
  f: (ctx) => new Response("standard"),
});

Deno.test("exportable composer any", async () => {
  assertEquals(
    composer.anyRequest()({
      f: () => "hello",
    })(dummyRequest),
    "hello",
  );
  assertEquals(
    composer.anyRequest(opt)({
      f: (ctx) => ctx.hello(),
    })(dummyRequest),
    "hello",
  );
  assertEquals(
    await composer.anyRequest()({
      f: async () => await Promise.resolve("hello"),
    })(dummyRequest),
    "hello",
  );
});

Deno.test("exportable composer ObjectNull", async () => {
  assertEquals(
    composer.objectNullRequest()({
      f: () => ({ hi: 1 }),
    })(dummyRequest),
    { hi: 1 },
  );
  assertEquals(
    composer.objectNullRequest(opt)({
      f: (ctx) => ({ hello: ctx.hello() }),
    })(dummyRequest),
    { hello: "hello" },
  );
  assertEquals(
    await composer.objectNullRequest()({
      f: async () => ({
        hello: await Promise.resolve("hello") + "!",
      }),
    })(dummyRequest),
    { hello: "hello!" },
  );
  assertEquals(
    composer.objectNullRequest()({
      f: () => null,
    })(dummyRequest),
    null,
  );
});

Deno.test("exportable composer petition", async () => {
  assertEquals(
    await Promise.resolve(composer.petition()(commonPetition)(dummyRequest))
      .then((x) => x.text()),
    "common",
  );
  assertEquals(
    await Promise.resolve(composer.petition()(requestPetition)(dummyRequest))
      .then((x) => x.text()),
    "standard",
  );
  assertEquals(
    await Promise.resolve(composer.petition()(responsePetition)(dummyRequest))
      .then((x) => x.text()),
    "response",
  );
});

==> vixeny-0.1.41.tgz: package/test/exportable/composer.test.ts <==
import { composer, plugins } from "../../main.ts";
import { assertEquals } from "@std/assert";
import { petitions } from "../../main.ts";
import { test } from "@cross/test";
const dummyRequest = new Request("http://heyINeedTOGoToSleep.com/");
const opt = plugins.globalOptions({
  cyclePlugin: {
    hello: {
      name: Symbol.for("hello"),
      isFunction: true,
      type: undefined,
      f: () => () => () => "hello",
    },
  },
});

const commonPetition = petitions.common()({
  path: "/common",
  f: () => "common",
});

const responsePetition = petitions.response()({
  path: "/response",
  r: () => new Response("response"),
});

const requestPetition = petitions.standard()({
  path: "/response",
  f: (ctx) => new Response("standard"),
});

test("exportable composer any", async () => {
  assertEquals(
    composer.anyRequest()({
      f: () => "hello",
    })(dummyRequest),
    "hello",
  );
  assertEquals(
    composer.anyRequest(opt)({
      f: (ctx) => ctx.hello(),
    })(dummyRequest),
    "hello",
  );
  assertEquals(
    await composer.anyRequest()({
      f: async () => await Promise.resolve("hello"),
    })(dummyRequest),
    "hello",
  );
});

test("exportable composer ObjectNull", async () => {
  assertEquals(
    composer.objectNullRequest()({
      f: () => ({ hi: 1 }),
    })(dummyRequest),
    { hi: 1 },
  );
  assertEquals(
    composer.objectNullRequest(opt)({
      f: (ctx) => ({ hello: ctx.hello() }),
    })(dummyRequest),
    { hello: "hello" },
  );
  assertEquals(
    await composer.objectNullRequest()({
      f: async () => ({
        hello: await Promise.resolve("hello") + "!",
      }),
    })(dummyRequest),
    { hello: "hello!" },
  );
  assertEquals(
    composer.objectNullRequest()({
      f: () => null,
    })(dummyRequest),
    null,
  );
});

test("exportable composer petition", async () => {
  assertEquals(
    await Promise.resolve(composer.petition(commonPetition)(dummyRequest))
      .then((x) => x.text()),
    "common",
  );
  assertEquals(
    await Promise.resolve(composer.petition(requestPetition)(dummyRequest))
      .then((x) => x.text()),
    "standard",
  );
  assertEquals(
    await Promise.resolve(composer.petition(responsePetition)(dummyRequest))
      .then((x) => x.text()),
    "response",
  );
});
